@@ -10,41 +10,23 @@ class SplitLink(TerminatingLink):
     right: TerminatingLink
     split: Callable[[Operation], bool] = Field(exclude=True)
 
-    async def aquery(self, operation: Operation, **kwargs) -> Operation:
-        future = (
-            self.left.aquery(operation, **kwargs)
-            if self.split(operation)
-            else self.right.aquery(operation, **kwargs)
-        )
-        return await future
-
-    async def asubscribe(self, operation: Operation, **kwargs) -> Operation:
+    async def aexecute(self, operation: Operation, **kwargs) -> Operation:
         iterator = (
-            self.left.asubscribe(operation, **kwargs)
+            self.left.aexecute(operation, **kwargs)
             if self.split(operation)
-            else self.right.asubscribe(operation, **kwargs)
+            else self.right.aexecute(operation, **kwargs)
         )
 
         async for res in iterator:
             yield res
 
-    def query(self, operation: Operation, **kwargs) -> Operation:
-        future = (
-            self.left.query(operation, **kwargs)
-            if self.split(operation)
-            else self.right.query(operation, **kwargs)
-        )
+    async def aconnect(self):
+        await self.left.aconnect()
+        await self.right.aconnect()
 
-        return future
-
-    def subscribe(self, operation: Operation, **kwargs) -> Operation:
-        iterator = (
-            self.left.subscribe(operation, **kwargs)
-            if self.split(operation)
-            else self.right.subscribe(operation, **kwargs)
-        )
-
-        return iterator
+    async def adisconnect(self):
+        await self.left.adisconnect()
+        await self.right.adisconnect()
 
     async def __aenter__(self):
         await self.left.__aenter__()
