@@ -1,4 +1,5 @@
 from koil.composition import KoiledModel
+from pydantic import Field
 from rath.errors import NotConnectedError, NotEnteredError
 from rath.links.base import TerminatingLink
 from typing import (
@@ -11,14 +12,42 @@ from typing import (
 from rath.operation import GraphQLResult, opify
 from contextvars import ContextVar
 from koil import unkoil_gen, unkoil
+from typing_extensions import Self
 
 
 current_rath = ContextVar("current_rath")
 
 
+class WrappedContext:
+    def __init__(self, value):
+        self.__value: ContextVar = value
+
+    def set(self, value):
+        return self.__value.set(value)
+
+    def reset(self, token):
+        self.__value.reset(token)
+        return
+
+    @classmethod
+    def __get_validators__(cls):
+        # one or more validators may be yielded which will be called in the
+        # order to validate the input, each validator will receive as an input
+        # the value returned from the previous validator
+        yield cls.validate
+
+    @classmethod
+    def validate(cls, v):
+        if isinstance(v, ContextVar):
+            return cls(v)
+        raise TypeError("Needs to be either a instance of ContextVar or a string")
+
+
 class Rath(KoiledModel):
     link: Optional[TerminatingLink] = None
-    set_context: bool = True
+    context: Optional[WrappedContext] = Field(
+        default_factory=lambda: WrappedContext(current_rath)
+    )
 
     _connected = False
     _entered = False
@@ -100,8 +129,8 @@ class Rath(KoiledModel):
 
     async def __aenter__(self):
         self._entered = True
-        if self.set_context:
-            current_rath.set(self)
+        if self.context:
+            self.context.set(self)
         await self.link.__aenter__()
         return self
 
@@ -111,8 +140,8 @@ class Rath(KoiledModel):
 
         await self.link.__aexit__(*args, **kwargs)
         self._entered = False
-        if self.set_context:
-            current_rath.set(None)
+        if self.context:
+            self.context.set(None)
 
     class Config:
         underscore_attrs_are_private = True
